Introduction
------------

scrapenhl2 is a python package for scraping and manipulating NHL data pulled from the NHL website.

Contact
--------
`Twitter
<http://www.twitter.com/muneebalamcu>`_.

Donations
---------
If you would like to support my work, please donate money to a charity of your choice. Many large charities do
great work all around the world, but don't forget that your support is often more critical for local/small charities.

You can vet a charity you're targeting using a `charity rating website <https://www.charitynavigator.org/>`_.

Change log
----------

9/24/17: Committed minimal structure.